==> dif-database-repository-2.3.4-8-sources.jar: pt/digitalis/dif/dem/managers/impl/model/DIFModelModule.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.dem.managers.impl.model.IAuthorizationService;
import pt.digitalis.dif.dem.managers.impl.model.impl.AuthorizationServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ECommerceServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.ICustomMessagesService;
import pt.digitalis.dif.dem.managers.impl.model.impl.CustomMessagesServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IIdentityService;
import pt.digitalis.dif.dem.managers.impl.model.impl.IdentityServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IPersistentActionsService;
import pt.digitalis.dif.dem.managers.impl.model.impl.PersistentActionsServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IPersistentFormsService;
import pt.digitalis.dif.dem.managers.impl.model.impl.PersistentFormsServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IErrorLoggingService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ErrorLoggingServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IAuditService;
import pt.digitalis.dif.dem.managers.impl.model.impl.AuditServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.impl.TemplateRepositoryServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IDDMService;
import pt.digitalis.dif.dem.managers.impl.model.impl.DDMServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IReportManagerService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ReportManagerServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IRGPDService;
import pt.digitalis.dif.dem.managers.impl.model.impl.RGPDServiceImpl;

import pt.digitalis.utils.ioc.modules.IIoCModule;
import pt.digitalis.utils.ioc.modules.IoCBinder;

/**
 * Module definition of the dif model.
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class DIFModelModule implements IIoCModule {

    /**
     * @see pt.digitalis.utils.ioc.modules.IIoCModule#configure(pt.digitalis.utils.ioc.modules.IoCBinder)
     */
    public void configure(IoCBinder binder) {
        binder.bind(IAuthorizationService.class, AuthorizationServiceImpl.class).asSingleton();
        binder.bind(IECommerceService.class, ECommerceServiceImpl.class).asSingleton();
        binder.bind(ICustomMessagesService.class, CustomMessagesServiceImpl.class).asSingleton();
        binder.bind(IIdentityService.class, IdentityServiceImpl.class).asSingleton();
        binder.bind(IPersistentActionsService.class, PersistentActionsServiceImpl.class).asSingleton();
        binder.bind(IPersistentFormsService.class, PersistentFormsServiceImpl.class).asSingleton();
        binder.bind(IErrorLoggingService.class, ErrorLoggingServiceImpl.class).asSingleton();
        binder.bind(IAuditService.class, AuditServiceImpl.class).asSingleton();
        binder.bind(ITemplateRepositoryService.class, TemplateRepositoryServiceImpl.class).asSingleton();
        binder.bind(IDDMService.class, DDMServiceImpl.class).asSingleton();
        binder.bind(IReportManagerService.class, ReportManagerServiceImpl.class).asSingleton();
        binder.bind(IRGPDService.class, RGPDServiceImpl.class).asSingleton();
    }
}

==> dif-database-repository-2.3.8-6-sources.jar: pt/digitalis/dif/dem/managers/impl/model/DIFModelModule.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.dem.managers.impl.model.IAuthorizationService;
import pt.digitalis.dif.dem.managers.impl.model.impl.AuthorizationServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ECommerceServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.ICustomMessagesService;
import pt.digitalis.dif.dem.managers.impl.model.impl.CustomMessagesServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IIdentityService;
import pt.digitalis.dif.dem.managers.impl.model.impl.IdentityServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IPersistentActionsService;
import pt.digitalis.dif.dem.managers.impl.model.impl.PersistentActionsServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IPersistentFormsService;
import pt.digitalis.dif.dem.managers.impl.model.impl.PersistentFormsServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IErrorLoggingService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ErrorLoggingServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.impl.TemplateRepositoryServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IDDMService;
import pt.digitalis.dif.dem.managers.impl.model.impl.DDMServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IReportManagerService;
import pt.digitalis.dif.dem.managers.impl.model.impl.ReportManagerServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IAccessLogService;
import pt.digitalis.dif.dem.managers.impl.model.impl.AccessLogServiceImpl;
import pt.digitalis.dif.dem.managers.impl.model.IRGPDService;
import pt.digitalis.dif.dem.managers.impl.model.impl.RGPDServiceImpl;

import pt.digitalis.utils.ioc.modules.IIoCModule;
import pt.digitalis.utils.ioc.modules.IoCBinder;

/**
 * Module definition of the dif model.
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class DIFModelModule implements IIoCModule {

    /**
     * @see pt.digitalis.utils.ioc.modules.IIoCModule#configure(pt.digitalis.utils.ioc.modules.IoCBinder)
     */
    public void configure(IoCBinder binder) {
        binder.bind(IAuthorizationService.class, AuthorizationServiceImpl.class).asSingleton();
        binder.bind(IECommerceService.class, ECommerceServiceImpl.class).asSingleton();
        binder.bind(ICustomMessagesService.class, CustomMessagesServiceImpl.class).asSingleton();
        binder.bind(IIdentityService.class, IdentityServiceImpl.class).asSingleton();
        binder.bind(IPersistentActionsService.class, PersistentActionsServiceImpl.class).asSingleton();
        binder.bind(IPersistentFormsService.class, PersistentFormsServiceImpl.class).asSingleton();
        binder.bind(IErrorLoggingService.class, ErrorLoggingServiceImpl.class).asSingleton();
        binder.bind(ITemplateRepositoryService.class, TemplateRepositoryServiceImpl.class).asSingleton();
        binder.bind(IDDMService.class, DDMServiceImpl.class).asSingleton();
        binder.bind(IReportManagerService.class, ReportManagerServiceImpl.class).asSingleton();
        binder.bind(IAccessLogService.class, AccessLogServiceImpl.class).asSingleton();
        binder.bind(IRGPDService.class, RGPDServiceImpl.class).asSingleton();
    }
}
